[![python-pkg](https://github.com/abearab/ezformer/actions/workflows/python-pkg.yml/badge.svg)](https://github.com/abearab/ezformer/actions/workflows/python-pkg.yml)

# ezformer
### Run enformer like models, get prediction tracks, and perform benchmarking